ProSHADE: Class Members

| ProSHADE 0.7.5.4 (MAR 2021) Protein Shape Detection

Here is a list of all documented class members with links to the class documentation for each member:

### - n -

- noIQRsFromMedianNaivePeak : ProSHADE_settings
- normaliseEMatrixValue() : ProSHADE_internal_data::ProSHADE_data
- normaliseMap() : ProSHADE_internal_data::ProSHADE_data , ProSHADE_settings
- noSpheres : ProSHADE_internal_data::ProSHADE_data